# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_upload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/business/vod_upload.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xce\x01\n\x12VodUrlUploadURLSet\x12\x11\n\tSourceUrl\x18\x01 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x02 \x01(\t\x12\x0b\n\x03Md5\x18\x03 \x01(\t\x12\x12\n\nTemplateId\x18\x04 \x01(\t\x12\r\n\x05Title\x18\x05 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04Tags\x18\x07 \x01(\t\x12\x10\n\x08\x43\x61tegory\x18\x08 \x01(\t\x12\x10\n\x08\x46ileName\x18\t \x01(\t\x12\x18\n\x10\x43lassificationId\x18\n \x01(\x03\"M\n\x12VodUrlResponseData\x12\x37\n\x04\x44\x61ta\x18\x01 \x03(\x0b\x32).Volcengine.Vod.Models.Business.ValuePair\"-\n\tValuePair\x12\r\n\x05JobId\x18\x01 \x01(\t\x12\x11\n\tSourceUrl\x18\x02 \x01(\t\"R\n\x0cVodQueryData\x12\x42\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodQueryUploadResult\"p\n\x14VodQueryUploadResult\x12@\n\rMediaInfoList\x18\x01 \x03(\x0b\x32).Volcengine.Vod.Models.Business.VodURLSet\x12\x16\n\x0eNotExistJobIds\x18\x02 \x03(\t\"^\n\rVodCommitData\x12M\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32?.Volcengine.Vod.Models.Business.VodCommitUploadInfoResponseData\"\xa7\x01\n\x1fVodCommitUploadInfoResponseData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x41\n\nSourceInfo\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x11\n\tPosterUri\x18\x03 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x04 \x01(\t\x12\x0b\n\x03Mid\x18\x05 \x01(\t\"\xc5\x01\n\tVodURLSet\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\r\n\x05JobId\x18\x02 \x01(\t\x12\x11\n\tSourceUrl\x18\x03 \x01(\t\x12\r\n\x05State\x18\x04 \x01(\t\x12\x0b\n\x03Vid\x18\x05 \x01(\t\x12\x11\n\tSpaceName\x18\x06 \x01(\t\x12\x11\n\tAccountId\x18\x07 \x01(\t\x12\x41\n\nSourceInfo\x18\x08 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\"`\n\x18VodApplyUploadInfoResult\x12\x44\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodApplyUploadInfoData\"a\n\x16VodApplyUploadInfoData\x12G\n\rUploadAddress\x18\x01 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodUploadAddress\"\xc2\x01\n\x10VodUploadAddress\x12@\n\nStoreInfos\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodStoreInfo\x12\x13\n\x0bUploadHosts\x18\x02 \x03(\t\x12\x43\n\x0cUploadHeader\x18\x03 \x03(\x0b\x32-.Volcengine.Vod.Models.Business.VodHeaderPair\x12\x12\n\nSessionKey\x18\x04 \x01(\t\".\n\x0cVodStoreInfo\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x0c\n\x04\x41uth\x18\x02 \x01(\t\"+\n\rVodHeaderPair\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"b\n\x19VodCommitUploadInfoResult\x12\x45\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodCommitUploadInfoData\"\x89\x01\n\x17VodCommitUploadInfoData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x11\n\tPosterUri\x18\x02 \x01(\t\x12\x41\n\nSourceInfo\x18\x03 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12\x0b\n\x03Mid\x18\x04 \x01(\tB\xcd\x01\n)com.volcengine.service.vod.model.businessB\tVodUploadP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODURLUPLOADURLSET = DESCRIPTOR.message_types_by_name['VodUrlUploadURLSet']
_VODURLRESPONSEDATA = DESCRIPTOR.message_types_by_name['VodUrlResponseData']
_VALUEPAIR = DESCRIPTOR.message_types_by_name['ValuePair']
_VODQUERYDATA = DESCRIPTOR.message_types_by_name['VodQueryData']
_VODQUERYUPLOADRESULT = DESCRIPTOR.message_types_by_name['VodQueryUploadResult']
_VODCOMMITDATA = DESCRIPTOR.message_types_by_name['VodCommitData']
_VODCOMMITUPLOADINFORESPONSEDATA = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponseData']
_VODURLSET = DESCRIPTOR.message_types_by_name['VodURLSet']
_VODAPPLYUPLOADINFORESULT = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResult']
_VODAPPLYUPLOADINFODATA = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoData']
_VODUPLOADADDRESS = DESCRIPTOR.message_types_by_name['VodUploadAddress']
_VODSTOREINFO = DESCRIPTOR.message_types_by_name['VodStoreInfo']
_VODHEADERPAIR = DESCRIPTOR.message_types_by_name['VodHeaderPair']
_VODCOMMITUPLOADINFORESULT = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResult']
_VODCOMMITUPLOADINFODATA = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoData']
VodUrlUploadURLSet = _reflection.GeneratedProtocolMessageType('VodUrlUploadURLSet', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADURLSET,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUrlUploadURLSet)
  })
_sym_db.RegisterMessage(VodUrlUploadURLSet)

VodUrlResponseData = _reflection.GeneratedProtocolMessageType('VodUrlResponseData', (_message.Message,), {
  'DESCRIPTOR' : _VODURLRESPONSEDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUrlResponseData)
  })
_sym_db.RegisterMessage(VodUrlResponseData)

ValuePair = _reflection.GeneratedProtocolMessageType('ValuePair', (_message.Message,), {
  'DESCRIPTOR' : _VALUEPAIR,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.ValuePair)
  })
_sym_db.RegisterMessage(ValuePair)

VodQueryData = _reflection.GeneratedProtocolMessageType('VodQueryData', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodQueryData)
  })
_sym_db.RegisterMessage(VodQueryData)

VodQueryUploadResult = _reflection.GeneratedProtocolMessageType('VodQueryUploadResult', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADRESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodQueryUploadResult)
  })
_sym_db.RegisterMessage(VodQueryUploadResult)

VodCommitData = _reflection.GeneratedProtocolMessageType('VodCommitData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitData)
  })
_sym_db.RegisterMessage(VodCommitData)

VodCommitUploadInfoResponseData = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponseData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSEDATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoResponseData)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponseData)

VodURLSet = _reflection.GeneratedProtocolMessageType('VodURLSet', (_message.Message,), {
  'DESCRIPTOR' : _VODURLSET,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodURLSet)
  })
_sym_db.RegisterMessage(VodURLSet)

VodApplyUploadInfoResult = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodApplyUploadInfoResult)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResult)

VodApplyUploadInfoData = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoData', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFODATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodApplyUploadInfoData)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoData)

VodUploadAddress = _reflection.GeneratedProtocolMessageType('VodUploadAddress', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADADDRESS,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUploadAddress)
  })
_sym_db.RegisterMessage(VodUploadAddress)

VodStoreInfo = _reflection.GeneratedProtocolMessageType('VodStoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSTOREINFO,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStoreInfo)
  })
_sym_db.RegisterMessage(VodStoreInfo)

VodHeaderPair = _reflection.GeneratedProtocolMessageType('VodHeaderPair', (_message.Message,), {
  'DESCRIPTOR' : _VODHEADERPAIR,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodHeaderPair)
  })
_sym_db.RegisterMessage(VodHeaderPair)

VodCommitUploadInfoResult = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESULT,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoResult)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResult)

VodCommitUploadInfoData = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoData', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFODATA,
  '__module__' : 'vod.business.vod_upload_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommitUploadInfoData)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\tVodUploadP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODURLUPLOADURLSET._serialized_start=97
  _VODURLUPLOADURLSET._serialized_end=303
  _VODURLRESPONSEDATA._serialized_start=305
  _VODURLRESPONSEDATA._serialized_end=382
  _VALUEPAIR._serialized_start=384
  _VALUEPAIR._serialized_end=429
  _VODQUERYDATA._serialized_start=431
  _VODQUERYDATA._serialized_end=513
  _VODQUERYUPLOADRESULT._serialized_start=515
  _VODQUERYUPLOADRESULT._serialized_end=627
  _VODCOMMITDATA._serialized_start=629
  _VODCOMMITDATA._serialized_end=723
  _VODCOMMITUPLOADINFORESPONSEDATA._serialized_start=726
  _VODCOMMITUPLOADINFORESPONSEDATA._serialized_end=893
  _VODURLSET._serialized_start=896
  _VODURLSET._serialized_end=1093
  _VODAPPLYUPLOADINFORESULT._serialized_start=1095
  _VODAPPLYUPLOADINFORESULT._serialized_end=1191
  _VODAPPLYUPLOADINFODATA._serialized_start=1193
  _VODAPPLYUPLOADINFODATA._serialized_end=1290
  _VODUPLOADADDRESS._serialized_start=1293
  _VODUPLOADADDRESS._serialized_end=1487
  _VODSTOREINFO._serialized_start=1489
  _VODSTOREINFO._serialized_end=1535
  _VODHEADERPAIR._serialized_start=1537
  _VODHEADERPAIR._serialized_end=1580
  _VODCOMMITUPLOADINFORESULT._serialized_start=1582
  _VODCOMMITUPLOADINFORESULT._serialized_end=1680
  _VODCOMMITUPLOADINFODATA._serialized_start=1683
  _VODCOMMITUPLOADINFODATA._serialized_end=1820
# @@protoc_insertion_point(module_scope)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    create_task_body = {
        "Name": "你好",
        "Resource": "9b39e17fb12444c78f20d6551469a6f0",
        "Type": 0,
        "NumberPoolNo": "NP162213338604093530",
        "Concurrency": 2,
        "PhoneList": [
            {
                "Phone": "your phone",
            }
        ],
        "StartTime": "2022-03-01 00:00:00",
        "EndTime": "2022-03-12 01:30:00",
        "SelectNumberRule": 5,
    }

    print(notify_service.create_task(create_task_body))



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    single_append_body = {
        "List": [
            {
                "Phone": "your phone",
                "Resource": "9b39e17fb12444c78f20d6551469a6f0",
                "NumberPoolNo": "NP162213338604093530",
                "NumberType": 0,
                "TriggerTime": "2022-03-12 19:18:00",
                "Type": 0,
                "SingleOpenId": "9b39e17fb12444c78f20d6551469a6e0"
            }
        ],
    }
    print(notify_service.single_batch_append(single_append_body))



#  -*- coding: utf-8 -*-
import datetime

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'Resources': ['example.com', 'example1.com'],
        'ResourceTags': [
            {'Key': 'userKey', 'Value': 'userVal'}
        ]
    }

    resp = svc.delete_resource_tags(body)
    print(resp)



import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo

SERVICE_VERSION = "2021-03-01"

service_info_map = {
    "cn-north-1": ServiceInfo("cdn.volcengineapi.com", {'accept': 'application/json', },
                              Credentials('', '', "CDN", "cn-north-1"), 60 * 5, 60 * 5, "https"),
}

api_info = {
    # 添加加速域名: https://www.volcengine.com/docs/6454/97340
    "AddCdnDomain": ApiInfo("POST", "/", {"Action": "AddCdnDomain", "Version": SERVICE_VERSION}, {}, {}),
    # 上线加速域名: https://www.volcengine.com/docs/6454/74667
    "StartCdnDomain": ApiInfo("POST", "/", {"Action": "StartCdnDomain", "Version": SERVICE_VERSION}, {}, {}),
    # 下线加速域名: https://www.volcengine.com/docs/6454/75129
    "StopCdnDomain": ApiInfo("POST", "/", {"Action": "StopCdnDomain", "Version": SERVICE_VERSION}, {}, {}),
    # 删除加速域名: https://www.volcengine.com/docs/6454/75130
    "DeleteCdnDomain": ApiInfo("POST", "/", {"Action": "DeleteCdnDomain", "Version": SERVICE_VERSION}, {}, {}),
    # 获取域名列表: https://www.volcengine.com/docs/6454/75269
    "ListCdnDomains": ApiInfo("POST", "/", {"Action": "ListCdnDomains", "Version": SERVICE_VERSION}, {}, {}),
    # 获取域名配置详情: https://www.volcengine.com/docs/6454/80320
    "DescribeCdnConfig": ApiInfo("POST", "/", {"Action": "DescribeCdnConfig", "Version": SERVICE_VERSION}, {}, {}),
    # 修改加速域名配置: https://www.volcengine.com/docs/6454/97266
    "UpdateCdnConfig": ApiInfo("POST", "/", {"Action": "UpdateCdnConfig", "Version": SERVICE_VERSION}, {}, {}),
    # 获取访问统计的细分数据: https://www.volcengine.com/docs/6454/70442
    "DescribeCdnData": ApiInfo("POST", "/", {"Action": "DescribeCdnData", "Version": SERVICE_VERSION}, {}, {}),
    # 获取访问统计的汇总数据: https://www.volcengine.com/docs/6454/96132
    "DescribeEdgeNrtDataSummary": ApiInfo("POST", "/",
                                          {"Action": "DescribeEdgeNrtDataSummary", "Version": SERVICE_VERSION}, {}, {}),
    # 获取回源统计的细分数据: https://www.volcengine.com/docs/6454/70443
    "DescribeCdnOriginData": ApiInfo("POST", "/", {"Action": "DescribeCdnOriginData", "Version": SERVICE_VERSION}, {},
                                     {}),
    # 获取回源统计的汇总数据: https://www.volcengine.com/docs/6454/96133
    "DescribeOriginNrtDataSummary": ApiInfo("POST", "/",
                                            {"Action": "DescribeOriginNrtDataSummary", "Version": SERVICE_VERSION}, {},
                                            {}),
    # 获取省份运营商的细分数据: https://www.volcengine.com/docs/6454/75159
    "DescribeCdnDataDetail": ApiInfo("POST", "/", {"Action": "DescribeCdnDataDetail", "Version": SERVICE_VERSION}, {},
                                     {}),
    # 获取独立访客的细分数据: https://www.volcengine.com/docs/6454/79321
    "DescribeEdgeStatisticalData": ApiInfo("POST", "/",
                                           {"Action": "DescribeEdgeStatisticalData", "Version": SERVICE_VERSION}, {},
                                           {}),
    # 获取访问统计的排行数据: https://www.volcengine.com/docs/6454/96145
    "DescribeEdgeTopNrtData": ApiInfo("POST", "/", {"Action": "DescribeEdgeTopNrtData", "Version": SERVICE_VERSION}, {},
                                      {}),
    # 获取回源数据的统计排序: https://www.volcengine.com/docs/6454/104892
    "DescribeOriginTopNrtData": ApiInfo("POST", "/", {"Action": "DescribeOriginTopNrtData", "Version": SERVICE_VERSION},
                                        {}, {}),
    # 获取访问状态码的统计排序: https://www.volcengine.com/docs/6454/104888
    "DescribeEdgeTopStatusCode": ApiInfo("POST", "/",
                                         {"Action": "DescribeEdgeTopStatusCode", "Version": SERVICE_VERSION}, {}, {}),
    # 获取回源状态码的统计排序: https://www.volcengine.com/docs/6454/104891
    "DescribeOriginTopStatusCode": ApiInfo("POST", "/",
                                           {"Action": "DescribeOriginTopStatusCode", "Version": SERVICE_VERSION}, {},
                                           {}),
    # 获取热点及访客排行数据: https://www.volcengine.com/docs/6454/79322
    "DescribeEdgeTopStatisticalData": ApiInfo("POST", "/",
                                              {"Action": "DescribeEdgeTopStatisticalData", "Version": SERVICE_VERSION},
                                              {}, {}),
    # 获取区域和 ISP 列表: https://www.volcengine.com/docs/6454/70445
    "DescribeCdnRegionAndIsp": ApiInfo("POST", "/", {"Action": "DescribeCdnRegionAndIsp", "Version": SERVICE_VERSION},
                                       {}, {}),
    # （Deprecated）查询域名排行数据: https://www.volcengine.com/docs/6454/70447?type=preview
    "DescribeCdnDomainTopData": ApiInfo("POST", "/", {"Action": "DescribeCdnDomainTopData", "Version": SERVICE_VERSION},
                                        {}, {}),
    # 查询账号计费方式: https://www.volcengine.com/docs/6454/78999
    "DescribeCdnService": ApiInfo("POST", "/", {"Action": "DescribeCdnService", "Version": SERVICE_VERSION}, {}, {}),
    # 获取计费指标的细分数据: https://www.volcengine.com/docs/6454/96167
    "DescribeAccountingData": ApiInfo("POST", "/", {"Action": "DescribeAccountingData", "Version": SERVICE_VERSION}, {},
                                      {}),
    # 提交刷新任务: https://www.volcengine.com/docs/6454/70438
    "SubmitRefreshTask": ApiInfo("POST", "/", {"Action": "SubmitRefreshTask", "Version": SERVICE_VERSION}, {}, {}),
    # 提交预热任务: https://www.volcengine.com/docs/6454/70436
    "SubmitPreloadTask": ApiInfo("POST", "/", {"Action": "SubmitPreloadTask", "Version": SERVICE_VERSION}, {}, {}),
    # 获取刷新预热任务信息: https://www.volcengine.com/docs/6454/70437
    "DescribeContentTasks": ApiInfo("POST", "/", {"Action": "DescribeContentTasks", "Version": SERVICE_VERSION}, {},
                                    {}),
    # 获取刷新预热配额信息: https://www.volcengine.com/docs/6454/70439
    "DescribeContentQuota": ApiInfo("POST", "/", {"Action": "DescribeContentQuota", "Version": SERVICE_VERSION}, {},
                                    {}),
    # 提交封禁任务: https://www.volcengine.com/docs/6454/79890
    "SubmitBlockTask": ApiInfo("POST", "/", {"Action": "SubmitBlockTask", "Version": SERVICE_VERSION}, {}, {}),
    # 提交解封任务: https://www.volcengine.com/docs/6454/79893
    "SubmitUnblockTask": ApiInfo("POST", "/", {"Action": "SubmitUnblockTask", "Version": SERVICE_VERSION}, {}, {}),
    # 获取封禁解封任务信息: https://www.volcengine.com/docs/6454/79906
    "DescribeContentBlockTasks": ApiInfo("POST", "/",
                                         {"Action": "DescribeContentBlockTasks", "Version": SERVICE_VERSION}, {}, {}),
    # 获取访问日志下载链接: https://www.volcengine.com/docs/6454/70446
    "DescribeCdnAccessLog": ApiInfo("POST", "/", {"Action": "DescribeCdnAccessLog", "Version": SERVICE_VERSION}, {},
                                    {}),
    # 获取 IP 归属信息: https://www.volcengine.com/docs/6454/75233
    "DescribeIPInfo": ApiInfo("POST", "/", {"Action": "DescribeIPInfo", "Version": SERVICE_VERSION}, {}, {}),
    # 批量获取 IP 归属信息: https://www.volcengine.com/docs/6454/106852
    "DescribeIPListInfo": ApiInfo("POST", "/", {"Action": "DescribeIPListInfo", "Version": SERVICE_VERSION}, {}, {}),
    # 获取回源节点 IP 列表: https://www.volcengine.com/docs/6454/75273
    "DescribeCdnUpperIp": ApiInfo("POST", "/", {"Action": "DescribeCdnUpperIp", "Version": SERVICE_VERSION}, {}, {}),
    # 添加资源标签: https://www.volcengine.com/docs/6454/80308
    "AddResourceTags": ApiInfo("POST", "/", {"Action": "AddResourceTags", "Version": SERVICE_VERSION}, {}, {}),
    # 更新资源标签: https://www.volcengine.com/docs/6454/80313
    "UpdateResourceTags": ApiInfo("POST", "/", {"Action": "UpdateResourceTags", "Version": SERVICE_VERSION}, {}, {}),
    # 查询标签清单: https://www.volcengine.com/docs/6454/80315
    "ListResourceTags": ApiInfo("POST", "/", {"Action": "ListResourceTags", "Version": SERVICE_VERSION}, {}, {}),
    # 删除资源标签: https://www.volcengine.com/docs/6454/80316
    "DeleteResourceTags": ApiInfo("POST", "/", {"Action": "DeleteResourceTags", "Version": SERVICE_VERSION}, {}, {}),
}


class CDNService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(CDNService, "_instance"):
            with CDNService._instance_lock:
                if not hasattr(CDNService, "_instance"):
                    CDNService._instance = object.__new__(cls)
        return CDNService._instance

    def __init__(self, region="cn-north-1"):
        self.service_info = CDNService.get_service_info(region)
        self.api_info = CDNService.get_api_info()
        super(CDNService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region_name):
        service_info = service_info_map.get(region_name, None)
        if not service_info:
            raise Exception('do not support region %s' % region_name)
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    def add_cdn_domain(self, params=None):
        if params is None:
            params = {}
        action = "AddCdnDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def start_cdn_domain(self, params=None):
        if params is None:
            params = {}
        action = "StartCdnDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def stop_cdn_domain(self, params=None):
        if params is None:
            params = {}
        action = "StopCdnDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def delete_cdn_domain(self, params=None):
        if params is None:
            params = {}
        action = "DeleteCdnDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def list_cdn_domains(self, params=None):
        if params is None:
            params = {}
        action = "ListCdnDomains"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_config(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnConfig"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def update_cdn_config(self, params=None):
        if params is None:
            params = {}
        action = "UpdateCdnConfig"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_edge_nrt_data_summary(self, params=None):
        if params is None:
            params = {}
        action = "DescribeEdgeNrtDataSummary"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_origin_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnOriginData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_nrt_data_summary(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginNrtDataSummary"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_data_detail(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnDataDetail"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_edge_statistical_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeEdgeStatisticalData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_edge_top_nrt_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeEdgeTopNrtData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_top_nrt_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginTopNrtData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_edge_top_status_code(self, params=None):
        if params is None:
            params = {}
        action = "DescribeEdgeTopStatusCode"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_top_status_code(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginTopStatusCode"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_edge_top_statistical_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeEdgeTopStatisticalData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_region_and_isp(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnRegionAndIsp"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_domain_top_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnDomainTopData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_service(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnService"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_accounting_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeAccountingData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def submit_refresh_task(self, params=None):
        if params is None:
            params = {}
        action = "SubmitRefreshTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def submit_preload_task(self, params=None):
        if params is None:
            params = {}
        action = "SubmitPreloadTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_content_tasks(self, params=None):
        if params is None:
            params = {}
        action = "DescribeContentTasks"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_content_quota(self, params=None):
        if params is None:
            params = {}
        action = "DescribeContentQuota"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def submit_block_task(self, params=None):
        if params is None:
            params = {}
        action = "SubmitBlockTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def submit_unblock_task(self, params=None):
        if params is None:
            params = {}
        action = "SubmitUnblockTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_content_block_tasks(self, params=None):
        if params is None:
            params = {}
        action = "DescribeContentBlockTasks"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_access_log(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnAccessLog"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_ip_info(self, params=None):
        if params is None:
            params = {}
        action = "DescribeIPInfo"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_iplist_info(self, params=None):
        if params is None:
            params = {}
        action = "DescribeIPListInfo"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_cdn_upper_ip(self, params=None):
        if params is None:
            params = {}
        action = "DescribeCdnUpperIp"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def add_resource_tags(self, params=None):
        if params is None:
            params = {}
        action = "AddResourceTags"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def update_resource_tags(self, params=None):
        if params is None:
            params = {}
        action = "UpdateResourceTags"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def list_resource_tags(self, params=None):
        if params is None:
            params = {}
        action = "ListResourceTags"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def delete_resource_tags(self, params=None):
        if params is None:
            params = {}
        action = "DeleteResourceTags"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from __future__ import print_function

import time

from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    visual_service = VisualService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    visual_service.set_ak('ak')
    visual_service.set_sk('sk')

    params = dict()

    form = {
        "image_base64": "image_base64_str"
    }

    resp = visual_service.video_scene_detect(form)
    print(resp)


# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import *

if __name__ == '__main__':
    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    # vod_service.set_ak('your ak')
    # vod_service.set_sk('your sk')

    try:
        req8 = VodGetSubtitleInfoListRequest()
        req8.Vid = 'vid'
        req8.FileIds = 'fileIds'
        req8.Formats = 'format'
        req8.Languages = 'language'
        req8.LanguageIds = 'languageIds'
        req8.SubtitleIds = 'subtitleIds'
        req8.Status = 'Published' #Published/Unpublished
        req8.Title = 'title'
        req8.Tag = 'tag'
        req8.Ssl = 'ssl'
        req8.Offset = 'offset'
        req8.PageSize = 'pageSize'

        resp8 = vod_service.get_subtitle_info_list(req8)
    except Exception:
        raise
    else:
        print(resp8)
        if resp8.ResponseMetadata.Error.Code == '':
            print('get subtitle info list success')
        else:
            print(resp8.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req9 = VodUpdateSubtitleStatusRequest()
        req9.Vid = 'vid'
        req9.FileIds = 'fileId1,fileId2'
        req9.Formats = 'format1,format2'
        req9.Languages = 'language1,language2'
        req9.Status = 'Published'          #Published/Unpublished

        resp9 = vod_service.update_subtitle_status(req9)
    except Exception:
        raise
    else:
        print(resp9)
        if resp9.ResponseMetadata.Error.Code == '':
            print('update subtitle status success')
        else:
            print(resp9.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req10 = VodUpdateSubtitleInfoRequest()
        req10.Vid = 'vid'
        req10.FileId = 'fileIds'
        req10.Format = 'format'
        req10.Language = 'language'
        req10.Title.value = 'title'
        req10.Tag.value = 'tag'

        resp10 = vod_service.update_subtitle_info(req10)
    except Exception:
        raise
    else:
        print(resp10)
        if resp10.ResponseMetadata.Error.Code == '':
            print('update subtitle info success')
        else:
            print(resp10.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req11 = VodGetSubtitleInfoListRequest()
        req11.Vid = 'vid'

        token = vod_service.get_subtitle_auth_token(req11, 60)
    except Exception:
        raise
    else:
        print(token)

    print('*' * 100)


# coding:utf-8
import base64
import hashlib
import hmac
import random
import sys
import uuid
from functools import reduce

from Crypto.Cipher import AES

from volcengine.const.Const import LETTER_RUNES
from zlib import crc32

try:
    from urllib import quote
except:
    from urllib.parse import quote


class Util(object):
    @staticmethod
    def norm_uri(path):
        return quote(path).replace('%2F', '/').replace('+', '%20')

    @staticmethod
    def norm_query(params):
        query = ''
        for key in sorted(params.keys()):
            if type(params[key]) == list:
                for k in params[key]:
                    query = query + quote(key, safe='-_.~') + '=' + quote(k, safe='-_.~') + '&'
            else:
                query = query + quote(key, safe='-_.~') + '=' + quote(params[key], safe='-_.~') + '&'
        query = query[:-1]
        return query.replace('+', '%20')

    @staticmethod
    def hmac_sha256(key, content):
        # type(key) == <class 'bytes'>
        if sys.version_info[0] == 3:
            return hmac.new(key, bytes(content, encoding='utf-8'), hashlib.sha256).digest()
        else:
            return hmac.new(key, bytes(content.encode('utf-8')), hashlib.sha256).digest()

    @staticmethod
    def hmac_sha1(key, content):
        # type(key) == <class 'bytes'>
        if sys.version_info[0] == 3:
            return hmac.new(key, bytes(content, encoding='utf-8'), hashlib.sha1).digest()
        else:
            return hmac.new(key, bytes(content.encode('utf-8')), hashlib.sha1).digest()

    @staticmethod
    def sha256(content):
        # type(content) == <class 'str'>
        if sys.version_info[0] == 3:
            if isinstance(content, str) is True:
                return hashlib.sha256(content.encode('utf-8')).hexdigest()
            else:
                return hashlib.sha256(content).hexdigest()
        else:
            if isinstance(content, (str, unicode)) is True:
                return hashlib.sha256(content.encode('utf-8')).hexdigest()
            else:
                return hashlib.sha256(content).hexdigest()

    @staticmethod
    def to_hex(content):
        lst = []
        for ch in content:
            if sys.version_info[0] == 3:
                hv = hex(ch).replace('0x', '')
            else:
                hv = hex(ord(ch)).replace('0x', '')
            if len(hv) == 1:
                hv = '0' + hv
            lst.append(hv)
        return reduce(lambda x, y: x + y, lst)

    @staticmethod
    def pad(plain_text):
        block_size = AES.block_size

        number_of_bytes_to_pad = block_size - len(plain_text) % block_size
        ascii_string = chr(0)
        padding_str = number_of_bytes_to_pad * ascii_string
        padded_plain_text = plain_text + padding_str
        return padded_plain_text

    @staticmethod
    def generate_access_key_id(prefix):
        uid = str(uuid.uuid4())
        uid_base64 = base64.b64encode(uid.replace('-', '').encode(encoding='utf-8'))

        s = uid_base64.decode().replace('=', '').replace('/', '').replace('+', '').replace('-', '')
        return prefix + s

    @staticmethod
    def rand_string_runes(length):
        return ''.join(random.sample(list(LETTER_RUNES), length))

    @staticmethod
    def aes_encrypt_cbc_with_base64(orig_data, key):
        # type(orig_data) == <class 'str'>
        # type(key) == <class 'bytes'>
        generator = AES.new(key, AES.MODE_CBC, key)
        if sys.version_info[0] == 3:
            crypt = generator.encrypt(Util.pad(orig_data).encode('utf-8'))
            return base64.b64encode(crypt).decode()
        else:
            crypt = generator.encrypt(Util.pad(orig_data))
            return base64.b64encode(crypt)

    @staticmethod
    def generate_secret_key():
        rand_str = Util.rand_string_runes(32)
        return Util.aes_encrypt_cbc_with_base64(rand_str, 'bytedance-isgood'.encode('utf-8'))

    @staticmethod
    def crc32(file_path):
        prev = 0
        for eachLine in open(file_path, "rb"):
            prev = crc32(eachLine, prev)
        return prev & 0xFFFFFFFF



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_play.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvod/business/vod_play.proto\x12\x1eVolcengine.Vod.Models.Business\"\xd8\x01\n\x1cVodGetOriginalPlayInfoResult\x12\x10\n\x08\x46ileType\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x02\x12\x0c\n\x04Size\x18\x03 \x01(\x01\x12\x0e\n\x06Height\x18\x04 \x01(\x05\x12\r\n\x05Width\x18\x05 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x06 \x01(\t\x12\r\n\x05\x43odec\x18\x07 \x01(\t\x12\x0f\n\x07\x42itrate\x18\x08 \x01(\x05\x12\x0b\n\x03Md5\x18\t \x01(\t\x12\x13\n\x0bMainPlayUrl\x18\n \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x0b \x01(\t\"H\n\x19VodPrivateDrmPlayAuthInfo\x12\x12\n\nPlayAuthId\x18\x01 \x01(\t\x12\x17\n\x0fPlayAuthContent\x18\x02 \x01(\t\"u\n\x1eVodGetPrivateDrmPlayAuthResult\x12S\n\x10PlayAuthInfoList\x18\x01 \x03(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodPrivateDrmPlayAuthInfo\"1\n\x1cVodGetHlsDecryptionKeyResult\x12\x11\n\tSecretKey\x18\x01 \x01(\t\"t\n!VodPlayInfoWithLiveTimeShiftScene\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x13\n\x0bMainPlayUrl\x18\x02 \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x03 \x01(\t\x12\x11\n\tUrlExpire\x18\x04 \x01(\x01\"\x85\x01\n*VodGetPlayInfoWithLiveTimeShiftSceneResult\x12W\n\x0cPlayInfoList\x18\x01 \x03(\x0b\x32\x41.Volcengine.Vod.Models.Business.VodPlayInfoWithLiveTimeShiftSceneB\xcb\x01\n)com.volcengine.service.vod.model.businessB\x07VodPlayP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETORIGINALPLAYINFORESULT = DESCRIPTOR.message_types_by_name['VodGetOriginalPlayInfoResult']
_VODPRIVATEDRMPLAYAUTHINFO = DESCRIPTOR.message_types_by_name['VodPrivateDrmPlayAuthInfo']
_VODGETPRIVATEDRMPLAYAUTHRESULT = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthResult']
_VODGETHLSDECRYPTIONKEYRESULT = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyResult']
_VODPLAYINFOWITHLIVETIMESHIFTSCENE = DESCRIPTOR.message_types_by_name['VodPlayInfoWithLiveTimeShiftScene']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESULT = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneResult']
VodGetOriginalPlayInfoResult = _reflection.GeneratedProtocolMessageType('VodGetOriginalPlayInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETORIGINALPLAYINFORESULT,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetOriginalPlayInfoResult)
  })
_sym_db.RegisterMessage(VodGetOriginalPlayInfoResult)

VodPrivateDrmPlayAuthInfo = _reflection.GeneratedProtocolMessageType('VodPrivateDrmPlayAuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODPRIVATEDRMPLAYAUTHINFO,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPrivateDrmPlayAuthInfo)
  })
_sym_db.RegisterMessage(VodPrivateDrmPlayAuthInfo)

VodGetPrivateDrmPlayAuthResult = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHRESULT,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetPrivateDrmPlayAuthResult)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthResult)

VodGetHlsDecryptionKeyResult = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYRESULT,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetHlsDecryptionKeyResult)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyResult)

VodPlayInfoWithLiveTimeShiftScene = _reflection.GeneratedProtocolMessageType('VodPlayInfoWithLiveTimeShiftScene', (_message.Message,), {
  'DESCRIPTOR' : _VODPLAYINFOWITHLIVETIMESHIFTSCENE,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPlayInfoWithLiveTimeShiftScene)
  })
_sym_db.RegisterMessage(VodPlayInfoWithLiveTimeShiftScene)

VodGetPlayInfoWithLiveTimeShiftSceneResult = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESULT,
  '__module__' : 'vod.business.vod_play_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetPlayInfoWithLiveTimeShiftSceneResult)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\007VodPlayP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETORIGINALPLAYINFORESULT._serialized_start=64
  _VODGETORIGINALPLAYINFORESULT._serialized_end=280
  _VODPRIVATEDRMPLAYAUTHINFO._serialized_start=282
  _VODPRIVATEDRMPLAYAUTHINFO._serialized_end=354
  _VODGETPRIVATEDRMPLAYAUTHRESULT._serialized_start=356
  _VODGETPRIVATEDRMPLAYAUTHRESULT._serialized_end=473
  _VODGETHLSDECRYPTIONKEYRESULT._serialized_start=475
  _VODGETHLSDECRYPTIONKEYRESULT._serialized_end=524
  _VODPLAYINFOWITHLIVETIMESHIFTSCENE._serialized_start=526
  _VODPLAYINFOWITHLIVETIMESHIFTSCENE._serialized_end=642
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESULT._serialized_start=645
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESULT._serialized_end=778
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.example.rtc.RtcService import RtcService

if __name__ == '__main__':
    # using your own AK and SK
    AK = 'Your_AK'
    SK = 'Your_SK'

    # Firstly , init an RTCService Class
    rtc_service = RtcService()

    # Then , Set your AK and SK
    rtc_service.set_ak(AK)
    rtc_service.set_sk(SK)

    # You can using this API now ! Here are some Examples
    body = dict()
    body['AppId'] = 'Your_AppId'
    body['StartTime'] = '2021-08-24T00:00:00+08:00'
    body['EndTime'] = '2021-08-25T00:00:00+08:00'
    body['Indicator'] = 'NetworkTransDelay'
    body['OS'] = 'mac'
    body['Network'] = 'wifi'

    body = json.dumps(body)
    resp = rtc_service.list_indicators(body)
    print(resp)




#  -*- coding: utf-8 -*-
from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        "Urls": "http://example.com/1.txt\nhttp://example.com/2.jpg",
    }

    resp = svc.submit_preload_task(body)
    print(resp)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    update_axn_form = {
        "NumberPoolNo": "NP162981168404095092",
        "SubId": "S16329006138991e7e1003",
        "UpdateType": "updatePhoneNoB",
        "PhoneNoB": "13700000004",
    }
    print(secretNumberService.update_axn(update_axn_form))



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    body = {
        "ActivityId": 1,
        "MediaId": 1,
        "OnlineStatus": 2
    }

    resp = livesaasService.update_media_online_status_api(body)
    # resp = await livesaasService.async_update_media_online_status_api(body)
    print(resp)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        "Vhost": "",
    }
    resp = live_service.list_vhost_transcode_preset(body)
    print(resp)



# coding:utf-8
from __future__ import print_function

from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    imagex_service.set_ak('ak')
    imagex_service.set_sk('sk')

    resp = imagex_service.get_image_info('imagex service id', 'image uri')
    print(resp)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    query_subscription_for_list_form = {
        "NumberPoolNo": "NP161156328504091435",
        "PhoneNoX": "13700000003",
        "Status": 1,
        "Offset": 0,
        "Limit": 20,
    }
    print(secretNumberService.query_subscription_for_list(query_subscription_for_list_form))



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetAllPlayInfoRequest

if __name__ == '__main__':
    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    # vod_service.set_ak('ak')
    # vod_service.set_sk('sk')
    try:
        req = VodGetAllPlayInfoRequest()
        req.Vids = 'your Vids'
        req.Formats = 'your Formats'
        req.Codecs = 'your Codecs'
        req.Definitions = 'your Definitions'
        req.FileTypes = 'your FileTypes'
        req.LogoTypes = 'your LogoTypes'
        req.NeedEncryptStream = 'your NeedEncryptStream'
        req.Ssl = 'your Ssl'
        req.NeedThumbs = 'your NeedThumbs'
        req.NeedBarrageMask = 'your NeedBarrageMask'
        req.CdnType = 'your CdnType'
        req.UnionInfo = 'your UnionInfo'
        req.PlayScene = 'your PlayScene'
        req.DrmExpireTimestamp = 'your DrmExpireTimestamp'
        req.HDRType = 'your HDRType'
        req.KeyFrameAlignmentVersion = 'your KeyFrameAlignmentVersion'
        req.UserAction = 'your UserAction'
        req.Quality = 'your Quality'
        resp = vod_service.get_all_play_info(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result)
        else:
            print(resp.ResponseMetadata.Error)
    print('*' * 100)



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetPlayInfoRequest

if __name__ == '__main__':

    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')
    try:
        vid = 'your vid'
        req = VodGetPlayInfoRequest()
        req.Vid = vid
        expire = 60  # seconds
        resp = vod_service.get_play_auth_token(req, expire)
    except Exception:
        raise
    else:
        print(resp)
    print('*' * 100)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    bind_axn_form = {
        "NumberPoolNo": "NP162981168404095092",
        "PhoneNoA": "13700000001",
        "PhoneNoB": "13700000002",
        "PhoneNoX": "13700000005",
        "ExpireTime": "1632920195",
        "UserData": "this is my user data",
    }
    print(secretNumberService.bind_axn(bind_axn_form))



#  -*- coding: utf-8 -*-
from __future__ import print_function

from volcengine.nlp.NLPService import NLPService

if __name__ == '__main__':
    nlp_service = NLPService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    nlp_service.set_ak('ak')
    nlp_service.set_sk('sk')

    params = dict()

    form = {
        "grade": "junior",
        "question": "My Beloved Teacher",
        "essay": "Sara, who came from Canada is our English Oral teacher. She is loved and respected by many students. What impressed me the most is that she is warm-hearted, generous and easy-going. She always stays optimistic and tries hard to understand every of her student. Besides, she often tells us some interesting stories and jokes in class, so as to make a happy atmosphere for us to study English. She loves teaching so much and has the eagerness to devote her life to Chinese education. Because of her outstanding achievements, she had won lots of rewards, one of which is “Model Teacher”.",
    }

    resp = nlp_service.essay_auto_grade(form)
    print(resp)



# coding:utf-8

class SignResult(object):
    def __init__(self):
        self.xdate = ''
        self.xCredential = ''
        self.xAlgorithm = ''
        self.xSignedHeaders = ''
        self.xSignedQueries = ''
        self.xSignature = ''

        self.authorization = ''

    def __str__(self):
        return '\n'.join(['%s:%s' % item for item in self.__dict__.items()])



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    params = {
        "ActivityId": 1
    }

    resp = livesaasService.get_activity_basic_config_api(params)
    # resp = await livesaasService.async_get_activity_basic_config_api(params)
    print(resp)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/request/request_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/request/request_vod.proto\x12\x1dVolcengine.Vod.Models.Request\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1dvod/business/vod_upload.proto\"\x84\x03\n\x18VodGetAllPlayInfoRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x02 \x01(\t\x12\x0e\n\x06\x43odecs\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65\x66initions\x18\x04 \x01(\t\x12\x11\n\tFileTypes\x18\x05 \x01(\t\x12\x11\n\tLogoTypes\x18\x06 \x01(\t\x12\x19\n\x11NeedEncryptStream\x18\x07 \x01(\t\x12\x0b\n\x03Ssl\x18\x08 \x01(\t\x12\x12\n\nNeedThumbs\x18\t \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\n \x01(\t\x12\x0f\n\x07\x43\x64nType\x18\x0b \x01(\t\x12\x11\n\tUnionInfo\x18\x0c \x01(\t\x12\x11\n\tPlayScene\x18\r \x01(\t\x12\x1a\n\x12\x44rmExpireTimestamp\x18\x0e \x01(\t\x12\x0f\n\x07HDRType\x18\x0f \x01(\t\x12 \n\x18KeyFrameAlignmentVersion\x18\x10 \x01(\t\x12\x12\n\nUserAction\x18\x11 \x01(\t\x12\x0f\n\x07Quality\x18\x12 \x01(\t\"\xc0\x02\n\x15VodGetPlayInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\r\n\x05\x43odec\x18\x03 \x01(\t\x12\x12\n\nDefinition\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08LogoType\x18\x06 \x01(\t\x12\x0e\n\x06\x42\x61se64\x18\x07 \x01(\t\x12\x0b\n\x03Ssl\x18\x08 \x01(\t\x12\x12\n\nNeedThumbs\x18\t \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\n \x01(\t\x12\x0f\n\x07\x43\x64nType\x18\x0b \x01(\t\x12\x11\n\tUnionInfo\x18\x0c \x01(\t\x12\x15\n\rHDRDefinition\x18\r \x01(\t\x12\x11\n\tPlayScene\x18\x0e \x01(\t\x12\x1a\n\x12\x44rmExpireTimestamp\x18\x0f \x01(\t\x12\x0f\n\x07Quality\x18\x10 \x01(\t\"g\n\x1fVodGetPrivateDrmPlayAuthRequest\x12\x0f\n\x07\x44rmType\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x13\n\x0bPlayAuthIds\x18\x03 \x01(\t\x12\x11\n\tUnionInfo\x18\x04 \x01(\t\"Q\n\x1dVodGetHlsDecryptionKeyRequest\x12\x14\n\x0c\x44rmAuthToken\x18\x01 \x01(\t\x12\n\n\x02\x41k\x18\x02 \x01(\t\x12\x0e\n\x06Source\x18\x03 \x01(\t\"\x98\x01\n+VodGetPlayInfoWithLiveTimeShiftSceneRequest\x12\x11\n\tStoreUris\x18\x01 \x01(\t\x12\x11\n\tSpaceName\x18\x02 \x01(\t\x12\x0b\n\x03Ssl\x18\x03 \x01(\t\x12\x17\n\x0f\x45xpireTimestamp\x18\x04 \x01(\t\x12\x1d\n\x15NeedComposeBucketName\x18\x05 \x01(\t\"m\n\x13VodUrlUploadRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x43\n\x07URLSets\x18\x02 \x03(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlUploadURLSet\"/\n\x1dVodQueryUploadTaskInfoRequest\x12\x0e\n\x06JobIds\x18\x01 \x01(\t\"x\n\x19VodApplyUploadInfoRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x12\n\nSessionKey\x18\x02 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x03 \x01(\x01\x12\x10\n\x08\x46ileType\x18\x04 \x01(\t\x12\x10\n\x08\x46ileName\x18\x05 \x01(\t\"w\n\x15VodUploadMediaRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x10\n\x08\x46ilePath\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\x12\x10\n\x08\x46ileName\x18\x05 \x01(\t\"\x8c\x01\n\x18VodUploadMaterialRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x10\n\x08\x46ilePath\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08\x46ileName\x18\x06 \x01(\t\"l\n\x1aVodCommitUploadInfoRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x12\n\nSessionKey\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\"=\n\x17VodUrlUploadJsonRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0f\n\x07URLSets\x18\x02 \x01(\t\".\n\x1eVodGetRecommendedPosterRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\"A\n\"VodUpdateMediaPublishStatusRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\t\"\x9c\x02\n\x19VodUpdateMediaInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12/\n\tPosterUri\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05Title\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x44\x65scription\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04Tags\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x10\x43lassificationId\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\'\n\x17VodGetMediaInfosRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\";\n\x15VodDeleteMediaRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x02 \x01(\t\"P\n\x1aVodDeleteTranscodesRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\"\xc6\x01\n\x16VodGetMediaListRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x0e\n\x06Status\x18\x03 \x01(\t\x12\r\n\x05Order\x18\x04 \x01(\t\x12\x0c\n\x04Tags\x18\x05 \x01(\t\x12\x11\n\tStartTime\x18\x06 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x07 \x01(\t\x12\x0e\n\x06Offset\x18\x08 \x01(\t\x12\x10\n\x08PageSize\x18\t \x01(\t\x12\x19\n\x11\x43lassificationIds\x18\n \x01(\t\"\xe6\x01\n\x1dVodGetSubtitleInfoListRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x11\n\tLanguages\x18\x03 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x04 \x01(\t\x12\x13\n\x0bLanguageIds\x18\x05 \x01(\t\x12\x13\n\x0bSubtitleIds\x18\x06 \x01(\t\x12\x0e\n\x06Status\x18\x07 \x01(\t\x12\r\n\x05Title\x18\x08 \x01(\t\x12\x0b\n\x03Tag\x18\t \x01(\t\x12\x0e\n\x06Offset\x18\n \x01(\t\x12\x10\n\x08PageSize\x18\x0b \x01(\t\x12\x0b\n\x03Ssl\x18\x0c \x01(\t\"r\n\x1eVodUpdateSubtitleStatusRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x11\n\tLanguages\x18\x03 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x04 \x01(\t\x12\x0e\n\x06Status\x18\x05 \x01(\t\"\xb5\x01\n\x1cVodUpdateSubtitleInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ileId\x18\x02 \x01(\t\x12\x10\n\x08Language\x18\x03 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x04 \x01(\t\x12+\n\x05Title\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03Tag\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"w\n VodGetAuditFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x19\n\x11MinNumberOfFrames\x18\x03 \x01(\t\x12\x19\n\x11MaxNumberOfFrames\x18\x04 \x01(\t\"\xa1\x02\n\x1dVodGetMLFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x10\n\x08\x46rameOpt\x18\x03 \x01(\t\x12\x10\n\x08\x46rameFps\x18\x04 \x01(\t\x12\x16\n\x0eNumberOfFrames\x18\x05 \x01(\t\x12\x14\n\x0c\x43utTimeMills\x18\x06 \x01(\t\x12\x16\n\x0eNeedFirstFrame\x18\x07 \x01(\t\x12\x15\n\rNeedLastFrame\x18\x08 \x01(\t\x12\x15\n\rStartTimeMill\x18\t \x01(\t\x12\x13\n\x0b\x45ndTimeMill\x18\n \x01(\t\x12\x19\n\x11MinNumberOfFrames\x18\x0b \x01(\t\x12\x19\n\x11MaxNumberOfFrames\x18\x0c \x01(\t\"U\n!VodGetBetterFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x11\n\tCoverRate\x18\x03 \x01(\t\"?\n\x1eVodGetAudioInfoForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"P\n/VodGetAutomaticSpeechRecognitionForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"I\n(VodGetAudioEventDetectionForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"q\n#VodCreateVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\r\n\x05Level\x18\x02 \x01(\x05\x12\x10\n\x08ParentId\x18\x03 \x01(\x03\x12\x16\n\x0e\x43lassification\x18\x04 \x01(\t\"j\n#VodUpdateVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\x12\x16\n\x0e\x43lassification\x18\x03 \x01(\t\"R\n#VodDeleteVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\"Q\n\"VodListVideoClassificationsRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\"&\n\x17VodListSnapshotsRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\"\xbc\x01\n\x17VodStartWorkflowRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x12\n\nTemplateId\x18\x02 \x01(\t\x12=\n\x05Input\x18\x03 \x01(\x0b\x32..Volcengine.Vod.Models.Business.WorkflowParams\x12\x10\n\x08Priority\x18\x04 \x01(\x05\x12\x14\n\x0c\x43\x61llbackArgs\x18\x05 \x01(\t\x12\x19\n\x11\x45nableLowPriority\x18\x06 \x01(\x08\"D\n!VodRetrieveTranscodeResultRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x12\n\nResultType\x18\x02 \x01(\t\"v\n\x15VodCreateSpaceRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x13\n\x0bProjectName\x18\x02 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06Region\x18\x04 \x01(\t\x12\x10\n\x08UserName\x18\x05 \x01(\t\"-\n\x18VodGetSpaceDetailRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\"4\n\x13VodListSpaceRequest\x12\x0e\n\x06Offset\x18\x01 \x01(\x01\x12\r\n\x05Limit\x18\x02 \x01(\x01\"u\n\x15VodUpdateSpaceRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x19\n\x11SourceProjectName\x18\x02 \x01(\t\x12\x19\n\x11TargetProjectName\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x04 \x01(\t\"^\n!VodUpdateSpaceUploadConfigRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x11\n\tConfigKey\x18\x02 \x01(\t\x12\x13\n\x0b\x43onfigValue\x18\x03 \x01(\t\")\n\x14VodListDomainRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\"O\n\x1eVodCreateCdnRefreshTaskRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0c\n\x04Urls\x18\x02 \x01(\t\x12\x0c\n\x04Type\x18\x03 \x01(\t\"A\n\x1eVodCreateCdnPreloadTaskRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0c\n\x04Urls\x18\x02 \x01(\t\"\xc2\x01\n\x16VodListCdnTasksRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0e\n\x06TaskId\x18\x02 \x01(\t\x12\x12\n\nDomainName\x18\x03 \x01(\t\x12\x10\n\x08TaskType\x18\x04 \x01(\t\x12\x0e\n\x06Status\x18\x05 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x06 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x07 \x01(\x05\x12\x0f\n\x07PageNum\x18\x08 \x01(\x05\x12\x10\n\x08PageSize\x18\t \x01(\x05\"n\n\x1aVodListCdnAccessLogRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x02 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x03 \x01(\x05\x12\x11\n\tSpaceName\x18\x04 \x01(\t\"p\n\x1dVodListCdnTopAccessUrlRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x02 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x03 \x01(\x05\x12\x10\n\x08SortType\x18\x04 \x01(\t\"\x8e\x01\n(VodDescribeVodDomainBandwidthDataRequest\x12\x12\n\nDomainList\x18\x01 \x01(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x13\n\x0b\x41ggregation\x18\x04 \x01(\x05\x12\x15\n\rBandwidthType\x18\x05 \x01(\t\"\x8f\x01\n\x1aVodListCdnUsageDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\x12\x0e\n\x06Metric\x18\x06 \x01(\t\"\x90\x01\n\x1bVodListCdnStatusDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\x12\x0e\n\x06Metric\x18\x06 \x01(\t\"\'\n\x18VodDescribeIPInfoRequest\x12\x0b\n\x03Ips\x18\x01 \x01(\t\"|\n\x17VodListCdnPvDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\"C\n!VodAddCallbackSubscriptionRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Url\x18\x02 \x01(\t\"h\n\x1aVodSetCallbackEventRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0e\n\x06\x45vents\x18\x02 \x01(\t\x12\x13\n\x0b\x41uthEnabled\x18\x03 \x01(\t\x12\x12\n\nPrivateKey\x18\x04 \x01(\t\"\xf4\x01\n&VodGetSmartStrategyLitePlayInfoRequest\x12\x0f\n\x07PlayUrl\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\r\n\x05\x43odec\x18\x03 \x01(\t\x12\x12\n\nDefinition\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08LogoType\x18\x06 \x01(\t\x12\x0b\n\x03Ssl\x18\x07 \x01(\t\x12\x12\n\nNeedThumbs\x18\x08 \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\t \x01(\t\x12\x11\n\tUnionInfo\x18\n \x01(\t\x12\x15\n\rHDRDefinition\x18\x0b \x01(\tB\xc8\x01\n(com.volcengine.service.vod.model.requestB\nVodRequestP\x01Z@github.com/volcengine/volc-sdk-golang/service/vod/models/request\xa0\x01\x01\xd8\x01\x01\xca\x02\x1fVolc\\Service\\Vod\\Models\\Request\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoRequest']
_VODGETPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetPlayInfoRequest']
_VODGETPRIVATEDRMPLAYAUTHREQUEST = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthRequest']
_VODGETHLSDECRYPTIONKEYREQUEST = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyRequest']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneRequest']
_VODURLUPLOADREQUEST = DESCRIPTOR.message_types_by_name['VodUrlUploadRequest']
_VODQUERYUPLOADTASKINFOREQUEST = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoRequest']
_VODAPPLYUPLOADINFOREQUEST = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoRequest']
_VODUPLOADMEDIAREQUEST = DESCRIPTOR.message_types_by_name['VodUploadMediaRequest']
_VODUPLOADMATERIALREQUEST = DESCRIPTOR.message_types_by_name['VodUploadMaterialRequest']
_VODCOMMITUPLOADINFOREQUEST = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoRequest']
_VODURLUPLOADJSONREQUEST = DESCRIPTOR.message_types_by_name['VodUrlUploadJsonRequest']
_VODGETRECOMMENDEDPOSTERREQUEST = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterRequest']
_VODUPDATEMEDIAPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusRequest']
_VODUPDATEMEDIAINFOREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoRequest']
_VODGETMEDIAINFOSREQUEST = DESCRIPTOR.message_types_by_name['VodGetMediaInfosRequest']
_VODDELETEMEDIAREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteMediaRequest']
_VODDELETETRANSCODESREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesRequest']
_VODGETMEDIALISTREQUEST = DESCRIPTOR.message_types_by_name['VodGetMediaListRequest']
_VODGETSUBTITLEINFOLISTREQUEST = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListRequest']
_VODUPDATESUBTITLESTATUSREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusRequest']
_VODUPDATESUBTITLEINFOREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoRequest']
_VODGETAUDITFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditRequest']
_VODGETMLFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditRequest']
_VODGETBETTERFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditRequest']
_VODGETAUDIOINFOFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditRequest']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditRequest']
_VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditRequest']
_VODCREATEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationRequest']
_VODUPDATEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationRequest']
_VODDELETEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationRequest']
_VODLISTVIDEOCLASSIFICATIONSREQUEST = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsRequest']
_VODLISTSNAPSHOTSREQUEST = DESCRIPTOR.message_types_by_name['VodListSnapshotsRequest']
_VODSTARTWORKFLOWREQUEST = DESCRIPTOR.message_types_by_name['VodStartWorkflowRequest']
_VODRETRIEVETRANSCODERESULTREQUEST = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultRequest']
_VODCREATESPACEREQUEST = DESCRIPTOR.message_types_by_name['VodCreateSpaceRequest']
_VODGETSPACEDETAILREQUEST = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailRequest']
_VODLISTSPACEREQUEST = DESCRIPTOR.message_types_by_name['VodListSpaceRequest']
_VODUPDATESPACEREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSpaceRequest']
_VODUPDATESPACEUPLOADCONFIGREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigRequest']
_VODLISTDOMAINREQUEST = DESCRIPTOR.message_types_by_name['VodListDomainRequest']
_VODCREATECDNREFRESHTASKREQUEST = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskRequest']
_VODCREATECDNPRELOADTASKREQUEST = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskRequest']
_VODLISTCDNTASKSREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnTasksRequest']
_VODLISTCDNACCESSLOGREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogRequest']
_VODLISTCDNTOPACCESSURLREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlRequest']
_VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataRequest']
_VODLISTCDNUSAGEDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnUsageDataRequest']
_VODLISTCDNSTATUSDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnStatusDataRequest']
_VODDESCRIBEIPINFOREQUEST = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoRequest']
_VODLISTCDNPVDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnPvDataRequest']
_VODADDCALLBACKSUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionRequest']
_VODSETCALLBACKEVENTREQUEST = DESCRIPTOR.message_types_by_name['VodSetCallbackEventRequest']
_VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoRequest']
VodGetAllPlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAllPlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoRequest)

VodGetPlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetPlayInfoRequest)

VodGetPrivateDrmPlayAuthRequest = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPrivateDrmPlayAuthRequest)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthRequest)

VodGetHlsDecryptionKeyRequest = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetHlsDecryptionKeyRequest)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyRequest)

VodGetPlayInfoWithLiveTimeShiftSceneRequest = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPlayInfoWithLiveTimeShiftSceneRequest)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneRequest)

VodUrlUploadRequest = _reflection.GeneratedProtocolMessageType('VodUrlUploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUrlUploadRequest)
  })
_sym_db.RegisterMessage(VodUrlUploadRequest)

VodQueryUploadTaskInfoRequest = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodQueryUploadTaskInfoRequest)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoRequest)

VodApplyUploadInfoRequest = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodApplyUploadInfoRequest)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoRequest)

VodUploadMediaRequest = _reflection.GeneratedProtocolMessageType('VodUploadMediaRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUploadMediaRequest)
  })
_sym_db.RegisterMessage(VodUploadMediaRequest)

VodUploadMaterialRequest = _reflection.GeneratedProtocolMessageType('VodUploadMaterialRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMATERIALREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUploadMaterialRequest)
  })
_sym_db.RegisterMessage(VodUploadMaterialRequest)

VodCommitUploadInfoRequest = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCommitUploadInfoRequest)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoRequest)

VodUrlUploadJsonRequest = _reflection.GeneratedProtocolMessageType('VodUrlUploadJsonRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADJSONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUrlUploadJsonRequest)
  })
_sym_db.RegisterMessage(VodUrlUploadJsonRequest)

VodGetRecommendedPosterRequest = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetRecommendedPosterRequest)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterRequest)

VodUpdateMediaPublishStatusRequest = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateMediaPublishStatusRequest)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusRequest)

VodUpdateMediaInfoRequest = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateMediaInfoRequest)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoRequest)

VodGetMediaInfosRequest = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMediaInfosRequest)
  })
_sym_db.RegisterMessage(VodGetMediaInfosRequest)

VodDeleteMediaRequest = _reflection.GeneratedProtocolMessageType('VodDeleteMediaRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteMediaRequest)
  })
_sym_db.RegisterMessage(VodDeleteMediaRequest)

VodDeleteTranscodesRequest = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteTranscodesRequest)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesRequest)

VodGetMediaListRequest = _reflection.GeneratedProtocolMessageType('VodGetMediaListRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMediaListRequest)
  })
_sym_db.RegisterMessage(VodGetMediaListRequest)

VodGetSubtitleInfoListRequest = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSubtitleInfoListRequest)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListRequest)

VodUpdateSubtitleStatusRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSubtitleStatusRequest)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusRequest)

VodUpdateSubtitleInfoRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSubtitleInfoRequest)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoRequest)

VodGetAuditFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAuditFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditRequest)

VodGetMLFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMLFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditRequest)

VodGetBetterFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetBetterFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditRequest)

VodGetAudioInfoForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAudioInfoForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditRequest)

VodGetAutomaticSpeechRecognitionForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAutomaticSpeechRecognitionForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditRequest)

VodGetAudioEventDetectionForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAudioEventDetectionForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditRequest)

VodCreateVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationRequest)

VodUpdateVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationRequest)

VodDeleteVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationRequest)

VodListVideoClassificationsRequest = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListVideoClassificationsRequest)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsRequest)

VodListSnapshotsRequest = _reflection.GeneratedProtocolMessageType('VodListSnapshotsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListSnapshotsRequest)
  })
_sym_db.RegisterMessage(VodListSnapshotsRequest)

VodStartWorkflowRequest = _reflection.GeneratedProtocolMessageType('VodStartWorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodStartWorkflowRequest)
  })
_sym_db.RegisterMessage(VodStartWorkflowRequest)

VodRetrieveTranscodeResultRequest = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodRetrieveTranscodeResultRequest)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultRequest)

VodCreateSpaceRequest = _reflection.GeneratedProtocolMessageType('VodCreateSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateSpaceRequest)
  })
_sym_db.RegisterMessage(VodCreateSpaceRequest)

VodGetSpaceDetailRequest = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSpaceDetailRequest)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailRequest)

VodListSpaceRequest = _reflection.GeneratedProtocolMessageType('VodListSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListSpaceRequest)
  })
_sym_db.RegisterMessage(VodListSpaceRequest)

VodUpdateSpaceRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSpaceRequest)
  })
_sym_db.RegisterMessage(VodUpdateSpaceRequest)

VodUpdateSpaceUploadConfigRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSpaceUploadConfigRequest)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigRequest)

VodListDomainRequest = _reflection.GeneratedProtocolMessageType('VodListDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListDomainRequest)
  })
_sym_db.RegisterMessage(VodListDomainRequest)

VodCreateCdnRefreshTaskRequest = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateCdnRefreshTaskRequest)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskRequest)

VodCreateCdnPreloadTaskRequest = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateCdnPreloadTaskRequest)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskRequest)

VodListCdnTasksRequest = _reflection.GeneratedProtocolMessageType('VodListCdnTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnTasksRequest)
  })
_sym_db.RegisterMessage(VodListCdnTasksRequest)

VodListCdnAccessLogRequest = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnAccessLogRequest)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogRequest)

VodListCdnTopAccessUrlRequest = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnTopAccessUrlRequest)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlRequest)

VodDescribeVodDomainBandwidthDataRequest = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDescribeVodDomainBandwidthDataRequest)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataRequest)

VodListCdnUsageDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnUsageDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNUSAGEDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnUsageDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnUsageDataRequest)

VodListCdnStatusDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnStatusDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNSTATUSDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnStatusDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnStatusDataRequest)

VodDescribeIPInfoRequest = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDescribeIPInfoRequest)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoRequest)

VodListCdnPvDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnPvDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNPVDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnPvDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnPvDataRequest)

VodAddCallbackSubscriptionRequest = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodAddCallbackSubscriptionRequest)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionRequest)

VodSetCallbackEventRequest = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodSetCallbackEventRequest)
  })
_sym_db.RegisterMessage(VodSetCallbackEventRequest)

VodGetSmartStrategyLitePlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSmartStrategyLitePlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.volcengine.service.vod.model.requestB\nVodRequestP\001Z@github.com/volcengine/volc-sdk-golang/service/vod/models/request\240\001\001\330\001\001\312\002\037Volc\\Service\\Vod\\Models\\Request\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFOREQUEST._serialized_start=161
  _VODGETALLPLAYINFOREQUEST._serialized_end=549
  _VODGETPLAYINFOREQUEST._serialized_start=552
  _VODGETPLAYINFOREQUEST._serialized_end=872
  _VODGETPRIVATEDRMPLAYAUTHREQUEST._serialized_start=874
  _VODGETPRIVATEDRMPLAYAUTHREQUEST._serialized_end=977
  _VODGETHLSDECRYPTIONKEYREQUEST._serialized_start=979
  _VODGETHLSDECRYPTIONKEYREQUEST._serialized_end=1060
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST._serialized_start=1063
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST._serialized_end=1215
  _VODURLUPLOADREQUEST._serialized_start=1217
  _VODURLUPLOADREQUEST._serialized_end=1326
  _VODQUERYUPLOADTASKINFOREQUEST._serialized_start=1328
  _VODQUERYUPLOADTASKINFOREQUEST._serialized_end=1375
  _VODAPPLYUPLOADINFOREQUEST._serialized_start=1377
  _VODAPPLYUPLOADINFOREQUEST._serialized_end=1497
  _VODUPLOADMEDIAREQUEST._serialized_start=1499
  _VODUPLOADMEDIAREQUEST._serialized_end=1618
  _VODUPLOADMATERIALREQUEST._serialized_start=1621
  _VODUPLOADMATERIALREQUEST._serialized_end=1761
  _VODCOMMITUPLOADINFOREQUEST._serialized_start=1763
  _VODCOMMITUPLOADINFOREQUEST._serialized_end=1871
  _VODURLUPLOADJSONREQUEST._serialized_start=1873
  _VODURLUPLOADJSONREQUEST._serialized_end=1934
  _VODGETRECOMMENDEDPOSTERREQUEST._serialized_start=1936
  _VODGETRECOMMENDEDPOSTERREQUEST._serialized_end=1982
  _VODUPDATEMEDIAPUBLISHSTATUSREQUEST._serialized_start=1984
  _VODUPDATEMEDIAPUBLISHSTATUSREQUEST._serialized_end=2049
  _VODUPDATEMEDIAINFOREQUEST._serialized_start=2052
  _VODUPDATEMEDIAINFOREQUEST._serialized_end=2336
  _VODGETMEDIAINFOSREQUEST._serialized_start=2338
  _VODGETMEDIAINFOSREQUEST._serialized_end=2377
  _VODDELETEMEDIAREQUEST._serialized_start=2379
  _VODDELETEMEDIAREQUEST._serialized_end=2438
  _VODDELETETRANSCODESREQUEST._serialized_start=2440
  _VODDELETETRANSCODESREQUEST._serialized_end=2520
  _VODGETMEDIALISTREQUEST._serialized_start=2523
  _VODGETMEDIALISTREQUEST._serialized_end=2721
  _VODGETSUBTITLEINFOLISTREQUEST._serialized_start=2724
  _VODGETSUBTITLEINFOLISTREQUEST._serialized_end=2954
  _VODUPDATESUBTITLESTATUSREQUEST._serialized_start=2956
  _VODUPDATESUBTITLESTATUSREQUEST._serialized_end=3070
  _VODUPDATESUBTITLEINFOREQUEST._serialized_start=3073
  _VODUPDATESUBTITLEINFOREQUEST._serialized_end=3254
  _VODGETAUDITFRAMESFORAUDITREQUEST._serialized_start=3256
  _VODGETAUDITFRAMESFORAUDITREQUEST._serialized_end=3375
  _VODGETMLFRAMESFORAUDITREQUEST._serialized_start=3378
  _VODGETMLFRAMESFORAUDITREQUEST._serialized_end=3667
  _VODGETBETTERFRAMESFORAUDITREQUEST._serialized_start=3669
  _VODGETBETTERFRAMESFORAUDITREQUEST._serialized_end=3754
  _VODGETAUDIOINFOFORAUDITREQUEST._serialized_start=3756
  _VODGETAUDIOINFOFORAUDITREQUEST._serialized_end=3819
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST._serialized_start=3821
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST._serialized_end=3901
  _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST._serialized_start=3903
  _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST._serialized_end=3976
  _VODCREATEVIDEOCLASSIFICATIONREQUEST._serialized_start=3978
  _VODCREATEVIDEOCLASSIFICATIONREQUEST._serialized_end=4091
  _VODUPDATEVIDEOCLASSIFICATIONREQUEST._serialized_start=4093
  _VODUPDATEVIDEOCLASSIFICATIONREQUEST._serialized_end=4199
  _VODDELETEVIDEOCLASSIFICATIONREQUEST._serialized_start=4201
  _VODDELETEVIDEOCLASSIFICATIONREQUEST._serialized_end=4283
  _VODLISTVIDEOCLASSIFICATIONSREQUEST._serialized_start=4285
  _VODLISTVIDEOCLASSIFICATIONSREQUEST._serialized_end=4366
  _VODLISTSNAPSHOTSREQUEST._serialized_start=4368
  _VODLISTSNAPSHOTSREQUEST._serialized_end=4406
  _VODSTARTWORKFLOWREQUEST._serialized_start=4409
  _VODSTARTWORKFLOWREQUEST._serialized_end=4597
  _VODRETRIEVETRANSCODERESULTREQUEST._serialized_start=4599
  _VODRETRIEVETRANSCODERESULTREQUEST._serialized_end=4667
  _VODCREATESPACEREQUEST._serialized_start=4669
  _VODCREATESPACEREQUEST._serialized_end=4787
  _VODGETSPACEDETAILREQUEST._serialized_start=4789
  _VODGETSPACEDETAILREQUEST._serialized_end=4834
  _VODLISTSPACEREQUEST._serialized_start=4836
  _VODLISTSPACEREQUEST._serialized_end=4888
  _VODUPDATESPACEREQUEST._serialized_start=4890
  _VODUPDATESPACEREQUEST._serialized_end=5007
  _VODUPDATESPACEUPLOADCONFIGREQUEST._serialized_start=5009
  _VODUPDATESPACEUPLOADCONFIGREQUEST._serialized_end=5103
  _VODLISTDOMAINREQUEST._serialized_start=5105
  _VODLISTDOMAINREQUEST._serialized_end=5146
  _VODCREATECDNREFRESHTASKREQUEST._serialized_start=5148
  _VODCREATECDNREFRESHTASKREQUEST._serialized_end=5227
  _VODCREATECDNPRELOADTASKREQUEST._serialized_start=5229
  _VODCREATECDNPRELOADTASKREQUEST._serialized_end=5294
  _VODLISTCDNTASKSREQUEST._serialized_start=5297
  _VODLISTCDNTASKSREQUEST._serialized_end=5491
  _VODLISTCDNACCESSLOGREQUEST._serialized_start=5493
  _VODLISTCDNACCESSLOGREQUEST._serialized_end=5603
  _VODLISTCDNTOPACCESSURLREQUEST._serialized_start=5605
  _VODLISTCDNTOPACCESSURLREQUEST._serialized_end=5717
  _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST._serialized_start=5720
  _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST._serialized_end=5862
  _VODLISTCDNUSAGEDATAREQUEST._serialized_start=5865
  _VODLISTCDNUSAGEDATAREQUEST._serialized_end=6008
  _VODLISTCDNSTATUSDATAREQUEST._serialized_start=6011
  _VODLISTCDNSTATUSDATAREQUEST._serialized_end=6155
  _VODDESCRIBEIPINFOREQUEST._serialized_start=6157
  _VODDESCRIBEIPINFOREQUEST._serialized_end=6196
  _VODLISTCDNPVDATAREQUEST._serialized_start=6198
  _VODLISTCDNPVDATAREQUEST._serialized_end=6322
  _VODADDCALLBACKSUBSCRIPTIONREQUEST._serialized_start=6324
  _VODADDCALLBACKSUBSCRIPTIONREQUEST._serialized_end=6391
  _VODSETCALLBACKEVENTREQUEST._serialized_start=6393
  _VODSETCALLBACKEVENTREQUEST._serialized_end=6497
  _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST._serialized_start=6500
  _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST._serialized_end=6744
# @@protoc_insertion_point(module_scope)



# coding: utf-8
import json
import logging
import os
import time
from collections import OrderedDict
try:
    from urllib.parse import urlencode
except ImportError:
    from urllib import urlencode

try:
    import configparser as configparser
except ImportError:
    import ConfigParser as configparser

import requests

from volcengine.Policy import SecurityToken2, InnerToken, ComplexEncoder
from volcengine.auth.SignerV4 import SignerV4
from volcengine.base.Request import Request
from volcengine.util.Util import *
from volcengine import VERSION


class Service(object):
    def __init__(self, service_info, api_info):
        self.service_info = service_info
        self.api_info = api_info
        self.session = requests.session()
        self.init()

    def init(self):
        if 'VOLC_ACCESSKEY' in os.environ and 'VOLC_SECRETKEY' in os.environ:
            self.service_info.credentials.set_ak(os.environ['VOLC_ACCESSKEY'])
            self.service_info.credentials.set_sk(os.environ['VOLC_SECRETKEY'])
        else:
            if os.environ.get('HOME', None) is None:
                return
            # 先尝试从credentials中读取ak、sk，credentials不存在则从config中读取
            path_ini = os.environ['HOME'] + '/.volc/credentials'
            path_json = os.environ['HOME'] + '/.volc/config'
            if os.path.isfile(path_ini):
                conf = configparser.ConfigParser()
                conf.read(path_ini)
                default_section, ak_option, sk_option = "default", "access_key_id", "secret_access_key"
                if conf.has_section(default_section):
                    if conf.has_option(default_section, ak_option):
                        ak = conf.get(default_section, ak_option)
                        self.service_info.credentials.set_ak(ak)
                    if conf.has_option(default_section, sk_option):
                        sk = conf.get(default_section, sk_option)
                        self.service_info.credentials.set_sk(sk)
            elif os.path.isfile(path_json):
                with open(path_json, 'r') as f:
                    try:
                        j = json.load(f)
                    except Exception:
                        logging.warning("%s is not json file", path_json)
                        return
                    if 'ak' in j:
                        self.service_info.credentials.set_ak(j['ak'])
                    if 'sk' in j:
                        self.service_info.credentials.set_sk(j['sk'])


    def set_ak(self, ak):
        self.service_info.credentials.set_ak(ak)

    def set_sk(self, sk):
        self.service_info.credentials.set_sk(sk)

    def set_host(self, host):
        self.service_info.host = host

    def set_scheme(self, scheme):
        self.service_info.scheme = scheme

    def get_sign_url(self, api, params):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]

        mquery = self.merge(api_info.query, params)
        r = Request()
        r.set_shema(self.service_info.scheme)
        r.set_method(api_info.method)
        r.set_path(api_info.path)
        r.set_query(mquery)

        return SignerV4.sign_url(r, self.service_info.credentials)

    def get(self, api, params, doseq=0):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]

        r = self.prepare_request(api_info, params, doseq)

        SignerV4.sign(r, self.service_info.credentials)

        url = r.build(doseq)
        resp = self.session.get(url, headers=r.headers,
                                timeout=(self.service_info.connection_timeout, self.service_info.socket_timeout))
        if resp.status_code == 200:
            return resp.text
        else:
            raise Exception(resp.text)

    def post(self, api, params, form):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]
        r = self.prepare_request(api_info, params)
        r.headers['Content-Type'] = 'application/x-www-form-urlencoded'
        r.form = self.merge(api_info.form, form)
        r.body = urlencode(r.form, True)
        SignerV4.sign(r, self.service_info.credentials)

        url = r.build()

        resp = self.session.post(url, headers=r.headers, data=r.form,
                                 timeout=(self.service_info.connection_timeout, self.service_info.socket_timeout))
        if resp.status_code == 200:
            return resp.text
        else:
            raise Exception(resp.text)

    def json(self, api, params, body):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]
        r = self.prepare_request(api_info, params)
        r.headers['Content-Type'] = 'application/json'
        r.body = body

        SignerV4.sign(r, self.service_info.credentials)

        url = r.build()
        resp = self.session.post(url, headers=r.headers, data=r.body,
                                 timeout=(self.service_info.connection_timeout, self.service_info.socket_timeout))
        if resp.status_code == 200:
            return json.dumps(resp.json())
        else:
            raise Exception(resp.text)

    def put(self, url, file_path, headers):
        with open(file_path, 'rb') as f:
            resp = self.session.put(url, headers=headers, data=f)
            if resp.status_code == 200:
                return True, resp.text
            else:
                return False, resp.text

    def put_data(self, url, data, headers):
        resp = self.session.put(url, headers=headers, data=data)
        if resp.status_code == 200:
            return True, resp.text
        else:
            return False, resp.text

    def prepare_request(self, api_info, params, doseq=0):
        for key in params:
            if type(params[key]) == int or type(params[key]) == float or type(params[key]) == bool:
                params[key] = str(params[key])
            elif sys.version_info[0] != 3:
                if type(params[key]) == unicode:
                    params[key] = params[key].encode('utf-8')
            elif type(params[key]) == list:
                if not doseq:
                    params[key] = ','.join(params[key])

        connection_timeout = self.service_info.connection_timeout
        socket_timeout = self.service_info.socket_timeout

        r = Request()
        r.set_shema(self.service_info.scheme)
        r.set_method(api_info.method)
        r.set_connection_timeout(connection_timeout)
        r.set_socket_timeout(socket_timeout)

        mheaders = self.merge(api_info.header, self.service_info.header)
        mheaders['Host'] = self.service_info.host
        mheaders['User-Agent'] = 'volc-sdk-python/' + VERSION
        r.set_headers(mheaders)

        mquery = self.merge(api_info.query, params)
        r.set_query(mquery)

        r.set_host(self.service_info.host)
        r.set_path(api_info.path)

        return r

    def merge(self, param1, param2):
        od = OrderedDict()
        for key in param1:
            od[key] = param1[key]

        for key in param2:
            od[key] = param2[key]

        return od

    def sign_sts2(self, policy, expire):
        sk = self.service_info.credentials.sk
        key = hashlib.md5(sk.encode('utf-8')).digest()

        sts = SecurityToken2()
        sts.access_key_id = Util.generate_access_key_id('AKTP')
        sts.secret_access_key = Util.generate_secret_key()
        now = int(time.time())
        sts.current_time = Service.to_rfc3339(now)

        if expire < 60:
            expire = 60
        expire = now + expire
        sts.expired_time = Service.to_rfc3339(expire)

        inner_token = InnerToken()
        inner_token.lt_access_key_id = self.service_info.credentials.ak
        inner_token.access_key_id = sts.access_key_id
        if policy is None:
            inner_token.policy_string = ''
        else:
            inner_token.policy_string = json.dumps(
                policy, cls=ComplexEncoder, sort_keys=True).replace(' ', '')
        inner_token.signed_secret_access_key = Util.aes_encrypt_cbc_with_base64(
            sts.secret_access_key, key)
        inner_token.expired_time = expire

        sign_str = '{}|{}|{}|{}|{}'.format(inner_token.lt_access_key_id, inner_token.access_key_id,
                                           inner_token.expired_time, inner_token.signed_secret_access_key,
                                           inner_token.policy_string)
        inner_token.signature = Util.to_hex(Util.hmac_sha256(key, sign_str))

        sts.session_token = 'STS2' + base64.b64encode(
            json.dumps(inner_token, cls=ComplexEncoder, sort_keys=True).replace(' ', '').encode('utf-8')).decode()
        return sts

    @staticmethod
    def to_rfc3339(t):
        format_time = time.strftime('%Y-%m-%dT%H:%M:%S%z', time.localtime(t))
        pos = format_time.find('+')
        if pos == -1:
            pos = format_time.find('-')
        return format_time[:pos + 3] + ':' + format_time[pos + 3:pos + 5]



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    upgrade_ax_to_axb_form = {
        "NumberPoolNo": "NP161156328504091435",
        "SubId": "S163290034831599ce523b",
        "PhoneNoB": "13700000002",
        "UserData": "this is my user data",
    }
    print(secretNumberService.upgrade_ax_to_axb(upgrade_ax_to_axb_form))



# coding:utf-8

from __future__ import print_function

import threading
from zlib import crc32

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class ImpServiceConfig(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(cls, "_instance"):
            with cls._instance_lock:
                if not hasattr(cls, "_instance"):
                    cls._instance = object.__new__(cls)
        return cls._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = ImpServiceConfig.get_service_info(region)
        self.api_info = ImpServiceConfig.get_api_info()
        self.domain_cache = {}
        self.fallback_domain_weights = {}
        self.update_interval = 10
        self.lock = threading.Lock()
        super(ImpServiceConfig, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                      Credentials('', '', 'imp', 'cn-north-1'), 10, 10),
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "SubmitJob": ApiInfo("GET", "/", {"Action": "SubmitJob", "Version": "2021-06-11"}, {}, {}),
            "KillJob": ApiInfo("GET", "/", {"Action": "KillJob", "Version": "2021-06-11"}, {}, {}),
            "RetrieveJob": ApiInfo("GET", "/", {"Action": "RetrieveJob", "Version": "2021-06-11"}, {}, {}),
        }
        return api_info

    @staticmethod
    def crc32(file_path):
        prev = 0
        for eachLine in open(file_path, "rb"):
            prev = crc32(eachLine, prev)
        return prev & 0xFFFFFFFF



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    delete_resource_param = {
       "ResourceKey": "4bb4b9b137264148998de1c227e9f652",
    }

    print(notify_service.delete_resource(delete_resource_param))



from __future__ import print_function

import time

from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    visual_service = VisualService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    visual_service.set_ak('ak')
    visual_service.set_sk('sk')

    form = {
        "urls":	["url_1", "url_2"],
        # "images_base64": ["img_b64_1", "img_b64_2"]
    }

    resp = visual_service.image_search_image_add(form)
    print(resp)



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    body = {
        "ActivityId": 1,
        "Name": "test",
        "LiveTime": 1628130120,
        "IsCoverImageEnable": 1,
        "CoverImageUrl": "",
        "CoverImageUrlDefault": "",
        "IsPcBackImageEnable": 1,
        "PcBackImageUrl": "",
        "PcBackImageUrlDefault": "",
        "IsMobileBackImageEnable": 1,
        "MobileBackImageUrl": "",
        "MobileBackImageUrlDefault": "",
        "IsPreviewVideoEnable": 0,
        "PreviewVideoUrl": "",
        "PreviewVideoVid": "",
        "PreviewVideoVidDefault": "",
        "IsPeopleCountEnable": 0,
        "IsHeaderImageEnable": 0,
        "HeaderImageUrl": "",
        "IsWatermarkImageEnable": 0,
        "WatermarkImageUrl": "",
        "IsThumbUpEnable": 0,
        "ThumbUpUrl": "",
        "ThumbUpUrlDefault": "",
        "IsShareIconEnable": 0,
        "ShareIconUrl": "",
        "ShareIconUrlDefault": "",
        "IsCommentTranslateEnable": 0,
        "Announcement": "",
        "IsAnnouncementEnable": 0,
        "BackgroundColor": "",
        "InteractionColor": "",
        "FontColor": "",
        "ColorThemeIndex": "",
        "IsPCHeaderImageEnable": 0,
        "PCHeaderImageUrl": "",
        "IsCountdownEnable": 0,
        "IsAutoStartEnable": 0,
        "IsPageLimitEnable": 0,
        "PageLimitType": "",
        "IsLanguageEnable": 0,
        "LanguageType": [],
        "SiteTags": [{
            "Index": 1,
            "Value": "",
            "DbIndex": 1,
            "Show": 0,
            "Name": ""
        }, {
            "Index": 2,
            "Value": "",
            "DbIndex": 3,
            "Show": 0,
            "Name": ""
        }, {
            "Index": 3,
            "Value": "",
            "DbIndex": 2,
            "Show": 0,
            "Name": ""
        }],
        "AutoStartType": 0,
        "IsPlayerTopEnable": 0,
        "PlayerTopType": [],
        "IsReplayAutoOnlineEnable": 1,
        "PreviewVideoId": 0,
        "AccountId": 0,
        "PreviewVideoReviewStatus": 0,
        "DefaultSubtitleLanguage": "",
        "SourceSubtitleLanguage": "",
        "OpenLiveAvextractorTask": 0,
        "IsTimeShift": 0,
        "PreviewVideoCoverImage": "",
        "PreviewVideoMediaName": "",
        "IsPreviewPromptEnable": 1,
        "PreviewPrompt": "直播即将开始，请稍候",
        "IsReservationEnable": 0,
        "ReservationTime": 0,
        "ReservationText": "",
        "WatermarkPosition": 0,
        "IsReplayBulletChat": 0,
        "PresenterChatColor": "",
        "IsLiveBulletChat": 0,
        "IsBackgroundBlur": 0,
        "FeedbackMessage": "",
        "IsFeedbackEnable": 0,
        "IsThumbUpNumberEnable": 1
    }

    resp = livesaasService.update_activity_basic_config_api(body)
    # resp = await livesaasService.async_update_activity_basic_config_api(body)
    print(resp)
